module.exports = defineTest({
	description: 'detect side-effects when dealing with update expressions'
});
